@@ -158,6 +158,9 @@ where
             trace!("{}", std::str::from_utf8(&body)?); // this may be very verbose
             let body = serde_json::from_slice(&body)?;
 
+            let xray_trace_id = &ctx.xray_trace_id.clone();
+            env::set_var("_X_AMZN_TRACE_ID", xray_trace_id);
+
             let request_id = &ctx.request_id.clone();
             let task = panic::catch_unwind(panic::AssertUnwindSafe(|| handler.call(body, ctx)));
 
